
# Type: orthologous to


a homology relationship between entities (typically genes) that diverged after a speciation event.

URI: [biolink:orthologous_to](https://w3id.org/biolink/vocab/orthologous_to)


## Domain and Range

[NamedThing](NamedThing.md) ->  <sub>0..*</sub> [NamedThing](NamedThing.md)

## Parents

 *  is_a: [homologous to](homologous_to.md)

## Children


## Used by

 * [NamedThing](NamedThing.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | RO:HOM0000017 |
|  | | WD:P684 |
| **In Subsets:** | | translator_minimal |

